==> haskell-skylighting-core-0.14.3-14.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-skylighting-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 skylighting-core
version:              0.14.3
visibility:           public
id:                   skylighting-core-0.14.3-Doguo3BFqgg4PCTJ9olxvN
key:                  skylighting-core-0.14.3-Doguo3BFqgg4PCTJ9olxvN
license:              BSD-3-Clause
copyright:            (C) 2016-2024 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/skylighting
synopsis:             syntax highlighting library
description:
    Skylighting is a syntax highlighting library.
    It derives its tokenizers from XML syntax
    definitions used by KDE'\''s KSyntaxHighlighting
    framework, so any syntax supported by that
    framework can be added. An optional command-line
    program is provided.
    Skylighting is intended to be the successor to
    highlighting-kate.
    This package provides the core highlighting
    functionality under a permissive license. It also
    bundles XML parser definitions licensed under the
    GPL.

category:             Text
abi:                  49b272c9592f811cf9f5f8617333e295
exposed:              True
exposed-modules:
    Skylighting.Core Skylighting.Loader Skylighting.Parser
    Skylighting.Regex Skylighting.Styles Skylighting.Tokenizer
    Skylighting.Types

hidden-modules:
    Regex.KDE Regex.KDE.Regex Regex.KDE.Compile Regex.KDE.Match

import-dirs:          /usr/lib/ghc-9.6.6/site-local/skylighting-core-0.14.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/skylighting-core-0.14.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/skylighting-core-0.14.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-skylighting-core
hs-libraries:         HSskylighting-core-0.14.3-Doguo3BFqgg4PCTJ9olxvN
depends:
    aeson-2.1.2.1-GojnAvr1Jep10WUNi5H1Pi
    attoparsec-0.14.4-8gkbEkDkw506qTMOo0v2nm base-4.18.2.1
    base64-bytestring-1.2.1.0-DIdtXjiFLF0sICzGCxvgr binary-0.8.9.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-3fPl2hvou1nDiCO1iE2i5z
    colour-2.3.6-H6QKK8UT9PiEnQ6wB0s1YD containers-0.6.7
    directory-1.3.8.5 filepath-1.4.300.1 mtl-2.3.1
    safe-0.3.21-6ywRAlXnRFuBscoqJeUz3o text-2.0.2 transformers-0.6.1.0
    utf8-string-1.0.2-6mVuGO0K0TVHYD6zuQNk2y
    xml-conduit-1.9.1.4-1cCl4mnX5as2ZihXQ5w8FO

haddock-interfaces:
    /usr/share/doc/haskell-skylighting-core/html/skylighting-core.haddock

haddock-html:         /usr/share/doc/haskell-skylighting-core/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-skylighting-core-0.14.3-16-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-skylighting-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 skylighting-core
version:              0.14.3
visibility:           public
id:                   skylighting-core-0.14.3-2rZAIOUbaN91Pp7XWprJjv
key:                  skylighting-core-0.14.3-2rZAIOUbaN91Pp7XWprJjv
license:              BSD-3-Clause
copyright:            (C) 2016-2024 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/skylighting
synopsis:             syntax highlighting library
description:
    Skylighting is a syntax highlighting library.
    It derives its tokenizers from XML syntax
    definitions used by KDE'\''s KSyntaxHighlighting
    framework, so any syntax supported by that
    framework can be added. An optional command-line
    program is provided.
    Skylighting is intended to be the successor to
    highlighting-kate.
    This package provides the core highlighting
    functionality under a permissive license. It also
    bundles XML parser definitions licensed under the
    GPL.

category:             Text
abi:                  37237a8714c12e727273539f37b747fa
exposed:              True
exposed-modules:
    Skylighting.Core Skylighting.Loader Skylighting.Parser
    Skylighting.Regex Skylighting.Styles Skylighting.Tokenizer
    Skylighting.Types

hidden-modules:
    Regex.KDE Regex.KDE.Regex Regex.KDE.Compile Regex.KDE.Match

import-dirs:          /usr/lib/ghc-9.6.6/site-local/skylighting-core-0.14.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/skylighting-core-0.14.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/skylighting-core-0.14.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-skylighting-core
hs-libraries:         HSskylighting-core-0.14.3-2rZAIOUbaN91Pp7XWprJjv
depends:
    aeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y
    attoparsec-0.14.4-68EOoedQqwu8mpKj0RmtvE base-4.18.2.1
    base64-bytestring-1.2.1.0-AZbYiNuTo1lLfA6t4c9Fhh binary-0.8.9.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-KNymwxzPyypAOJSQGx0ioI
    colour-2.3.6-DLRFrLUBudd2Y8gC5KfK2z containers-0.6.7
    directory-1.3.8.5 filepath-1.4.300.1 mtl-2.3.1
    safe-0.3.21-7oQO4KcgDWt1YhK3ifcAwa text-2.0.2 transformers-0.6.1.0
    utf8-string-1.0.2-GrV0vD7epd2Fw38ZtPT1hv
    xml-conduit-1.9.1.4-AWUHrHEyod1C1UJeqVfDQt

haddock-interfaces:
    /usr/share/doc/haskell-skylighting-core/html/skylighting-core.haddock

haddock-html:         /usr/share/doc/haskell-skylighting-core/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
